@@ -14,10 +14,6 @@ if __name__ == '__main__':
 	obs = OBSStudio(
 		r'D:\workbench-2020\Software\AutomatedValidation\SE-VALIDATION\OBSStudio\OBS-Studio-22.0.2-Full-x64\bin\64bit\obs64.exe')
 
-	if False:
-		cmd = r'cmd /c start "explorer.exe shel------l:C:\Program Files\WindowsApps\Microsoft.ZuneMusic_3.6.25021.0_x64__8wekyb3d8bbwe!Microsoft.ZuneMusic" "D:\Music\Mr_Sunny_Face.mp3"'
-		os.system(cmd)
-
 	###############################################################################
 	# Remove Downloads\pywinauto_recorder.dist.zip and R:\pywinauto_recorder.dist #
 	###############################################################################
