@@ -90,7 +90,7 @@ def write_in_file(events):
                     p1 = get_relative_path(common_path, p1)
                     p2 = get_relative_path(common_path, p2)
                 script += 'drag_and_drop(u"' + escape_special_char(p1) + '%(' + dx1 + ',' + dy1 + ')", '
-                script += + escape_special_char(p2) + '%(' + dx2 + ',' + dy2 + ')")\n'
+                script += 'u"' + escape_special_char(p2) + '%(' + dx2 + ',' + dy2 + ')")\n'
             elif type(e_i) is ClickEvent:
                 p = e_i.path
                 dx, dy = "{:.2f}".format(round(e_i.dx * 100, 2)), "{:.2f}".format(round(e_i.dy * 100, 2))
@@ -104,6 +104,8 @@ def write_in_file(events):
             elif type(e_i) is FindEvent:
                 p = e_i.path
                 dx, dy = "{:.2f}".format(round(e_i.dx * 100, 2)), "{:.2f}".format(round(e_i.dy * 100, 2))
+                if common_path:
+                    p = get_relative_path(common_path, p)
                 script += 'wrapper = find(u"' + escape_special_char(p) + '%(' + dx + ',' + dy + ')")\n'
             elif type(e_i) is MenuEvent:
                 p, m_p = e_i.path, e_i.menu_path
@@ -288,12 +290,15 @@ def process_drag_and_drop_or_click_events(events, i):
 def get_relative_path(common_path, path):
     if not path:
         return ''
+    # TODO: check if common_path is the beginning of path
     path = path[len(common_path) + len(path_separator):]
     entry_list = get_entry_list(path)
     str_name, str_type, y_x, dx_dy = get_entry(entry_list[-1])
     if (y_x is not None) and not is_int(y_x[0]):
         y_x[0] = y_x[0][len(common_path) + 2:]
         path = path_separator.join(entry_list[:-1]) + path_separator + str_name
+        if path == path_separator:
+            path = ''
         path = path + type_separator + str_type + "#[" + y_x[0] + "," + str(y_x[1]) + "]"
         if dx_dy is not None:
             path = path + "%(" + str(dx_dy[0]) + "," + str(dx_dy[1]) + ")"
@@ -562,29 +567,16 @@ def overlay_add_progress_icon(main_overlay, i, x, y):
             color=(0, 255, 0), thickness=1, brush=oaam.Brush.solid, brush_color=(0, 200, 0))
 
 
-def overlay_add_search_mode_icon(main_overlay, x, y):
+def overlay_add_search_mode_icon(main_overlay, hicon, x, y):
     main_overlay.add(
-        geometry=oaam.Shape.rectangle, x=x, y=y, width=40, height=40,
-        color=(0, 0, 0), thickness=1, brush=oaam.Brush.solid, brush_color=(255, 255, 254))
-    main_overlay.add(
-        geometry=oaam.Shape.triangle,
-        xyrgb_array=((x + 1, y + 1, 255, 255, 254), (x + 1, y + 40, 128, 128, 128), (x + 39, y + 40, 255, 255, 254)),
-        thickness=0)
-    main_overlay.add(
-        geometry=oaam.Shape.rectangle, x=x + 5, y=y + 5, width=30, height=30,
-        color=(0, 0, 0), thickness=1, brush=oaam.Brush.solid, brush_color=(0, 255, 0))
-    main_overlay.add(
-        geometry=oaam.Shape.rectangle, x=x + 10, y=y + 5 + 1 * 8, width=15, height=6,
-        color=(0, 255, 0), thickness=1, brush=oaam.Brush.solid, brush_color=(255, 0, 0))
-    main_overlay.add(
-        geometry=oaam.Shape.rectangle, x=x + 10, y=y + 5 + 2 * 8, width=15, height=6,
-        color=(0, 255, 0), thickness=1, brush=oaam.Brush.solid, brush_color=(255, 0, 0))
+        geometry=oaam.Shape.image, hicon=hicon, x=x, y=y)
 
 
 class Recorder(Thread):
     def __init__(self):
         Thread.__init__(self)
         self.main_overlay = oaam.Overlay(transparency=0.5)
+        self.info_overlay = oaam.Overlay(transparency=0.0)
         self.desktop = pywinauto.Desktop(backend='uia', allow_magic_lookup=False)
         self.daemon = True
         self.event_list = []
@@ -594,6 +586,8 @@ class Recorder(Thread):
         self.mouse_x_inside = 99
         self.mouse_y_inside = 99
         self.hicon = None
+        self.hicon_light_on = None
+        self.hicon_light_off = None
         self.started_recording_with_keyboard = False
         self.start()
 
@@ -737,21 +731,70 @@ class Recorder(Thread):
                 str_dx, str_dy = "{:.2f}".format(round(dx * 100, 2)), "{:.2f}".format(round(dy * 100, 2))
                 self.main_overlay.add(
                     geometry=oaam.Shape.image, hicon=self.hicon, x=x, y=l_e_e.rectangle.top - 70)
-                l_e_e_path = escape_special_char(l_e_e.path)
-                i = l_e_e_path.find(path_separator)
-                window_title = l_e_e_path[0:i]
-                element_path = l_e_e_path[i+len(path_separator):]
+                i = l_e_e.path.find(path_separator)
+                window_title = l_e_e.path[0:i]
+                #element_path = l_e_e.path[i+len(path_separator):]
+                p = get_relative_path(window_title, l_e_e.path)
                 pyperclip.copy(
-                    'with Window(u"' + window_title + '"):\n' +
-                    '\twrapper = find(u"' + element_path + '%(' + str_dx + ',' + str_dy + ')")\n')
+                    'with Window(u"' + escape_special_char(window_title) + '"):\n' +
+                    '\twrapper = find(u"' + escape_special_char(p) + '%(' + str_dx + ',' + str_dy + ')")\n')
                 if self.event_list:
                     self.event_list.append(FindEvent(path=l_e_e.path, dx=dx, dy=dy, time=time.time()))
         elif self.mode == 'Record':
             self.event_list.append(e)
 
+    def __display_info_tip(self, x, y, wrapper):
+        r = wrapper.rectangle()
+        if x - r.width() > 300:
+            info_left = x - r.width() - 300
+        else:
+            info_left = x
+        if y - r.height() > 100:
+            info_top = r.top - r.height() - 20
+            info_dir = -1
+        else:
+            info_top = r.top + r.height() + 20
+            info_dir = 1
+        self.main_overlay.add(
+            geometry=oaam.Shape.rectangle, x=info_left, y=info_top, width=300, height=25,
+            thickness=1, color=(0, 0, 0), brush=oaam.Brush.solid, brush_color=(254, 222, 255))
+        self.info_overlay.add(
+            x=info_left + 5, y=info_top + info_dir, width=300,
+            height=25,
+            text="Name: " + wrapper.element_info.name,
+            font_size=16, text_color=(0, 0, 0), color=(254, 255, 255),
+            geometry=oaam.Shape.rectangle, thickness=0
+        )
+        self.main_overlay.add(
+            geometry=oaam.Shape.rectangle, x=info_left, y=info_top + info_dir * 25 * (2 - 1), width=300, height=25,
+            thickness=1, color=(0, 0, 0), brush=oaam.Brush.solid, brush_color=(254, 25, 255))
+        self.info_overlay.add(
+            x=info_left + 5, y=info_top + info_dir * 25 * (2 - 1), width=300,
+            height=25,
+            text="Type:" + wrapper.element_info.control_type,
+            font_size=16, text_color=(0, 0, 0), color=(254, 255, 255),
+            geometry=oaam.Shape.rectangle, thickness=0
+        )
+        has_value = getattr(wrapper, "get_value", None)
+        if callable(has_value):
+            self.main_overlay.add(
+                geometry=oaam.Shape.rectangle, x=info_left, y=info_top + info_dir * 25 * (3 - 1), width=300, height=25,
+                thickness=1, color=(0, 0, 0), brush=oaam.Brush.solid, brush_color=(254, 25, 255))
+            self.info_overlay.add(
+                x=info_left + 5, y=info_top + info_dir * 25 * (3 - 1), width=300,
+                height=25,
+                text="Value: " + wrapper.get_value(),
+                font_size=16, text_color=(0, 0, 0), color=(254, 255, 255),
+                geometry=oaam.Shape.rectangle, thickness=0
+            )
+
     def run(self):
+        import comtypes.client
+        print("COMPTYPES GEN FOLDER:", comtypes.client._code_cache._find_gen_dir())
+
         dir_path = os.path.dirname(os.path.realpath(__file__))
-        print(dir_path)
+        print("PYWINAUTO RECORDER FOLDER:", dir_path)
+
         keyboard.hook(self.__key_on)
         mouse.hook(self.__mouse_on)
         keyboard.start_recording()
@@ -764,6 +807,8 @@ class Recorder(Thread):
             os.system(dir_path + r"\pywinauto_recorder.exe --no_splash_screen")
             sys.exit(1)
         self.hicon = oaam.load_png(dir_path + r'\copy_clipboard.png', 64, 64)
+        self.hicon_light_on = oaam.load_png(dir_path + r'\light_on.png', 40, 40)
+        self.hicon_light_off = oaam.load_png(dir_path + r'\light_off.png', 40, 40)
         unique_candidate = None
         elements = []
         i = 0
@@ -774,10 +819,12 @@ class Recorder(Thread):
         while self.mode != "Quit":
             try:
                 self.main_overlay.clear_all()
+                self.info_overlay.clear_all()
                 x, y = win32api.GetCursorPos()
                 wrapper = self.desktop.from_point(x, y)
                 if wrapper is None:
                     continue
+                self.__display_info_tip(x, y, wrapper)
                 wrapper_path = get_wrapper_path(wrapper)
                 if not wrapper_path:
                     continue
@@ -831,9 +878,10 @@ class Recorder(Thread):
                     while self.mode == 'Stop':
                         time.sleep(1.0)
                 overlay_add_progress_icon(self.main_overlay, i, 60, 10)
-                overlay_add_search_mode_icon(self.main_overlay, 110, 10)
+                overlay_add_search_mode_icon(self.main_overlay, self.hicon_light_on, 110, 10)
                 i = i + 1
                 self.main_overlay.refresh()
+                self.info_overlay.refresh()
                 time.sleep(0.005)  # main_overlay.clear_all() doit attendre la fin de main_overlay.refresh()
             except Exception as e:
                 exc_type, exc_value, exc_traceback = sys.exc_info()
